@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,17 +7,20 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef _DYNAMIC_COLOR_H_
 #define _DYNAMIC_COLOR_H_
 
+#include "common.h"
 
+/* system interface headers */
 #include <string>
 #include <vector>
 #include <iostream>
 
+
 typedef struct sequenceList {
   float period;
   float offset;
@@ -57,7 +60,7 @@ class DynamicColor {
     void addClampDown(int channel, const float clampDown[3]);
 
     void finalize();
-    void update(float time);
+    void update(double time);
 
     bool canHaveAlpha() const;
     const float* getColor() const;
@@ -123,3 +126,12 @@ extern DynamicColorManager DYNCOLORMGR;
 
 
 #endif //_DYNAMIC_COLOR_H_
+
+// Local Variables: ***
+// mode:C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
+
