@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,16 +7,17 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef	BZF_OBSTACLE_MODIFIER_H
 #define	BZF_OBSTACLE_MODIFIER_H
 
+// common headers
+#include "BzMaterial.h"
 
 class Obstacle;
 class GroupInstance;
-class BzMaterial;
 
 
 class ObstacleModifier {
@@ -29,6 +30,8 @@ class ObstacleModifier {
 
     void execute(Obstacle* obstacle) const;
 
+    void getMaterialMap(const MaterialSet& matSet, MaterialMap& matMap) const;
+
   private:
     bool modifyTeam; // only for bases
     int team;
@@ -38,6 +41,7 @@ class ObstacleModifier {
     int phydrv;
     bool modifyMaterial; // swaps the whole thing
     const BzMaterial* material;
+    MaterialMap matMap;
 
     bool driveThrough;
     bool shootThrough;
