@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -67,6 +67,9 @@ class MainWindow {
 
     void		showWindow(bool = true);
     void		warpMouse();
+    void		warpMouse(int mx, int my);
+    void		warpMouseCenterX();
+    void		warpMouseCenterY();
     void		grabMouse();
     void		enableGrabMouse(bool on);
     bool		isGrabEnabled(void);
@@ -98,6 +101,8 @@ class MainWindow {
 
     static void		resizeCB(void*);
 
+    inline int		getYOffset() const;
+
   private:
     BzfWindow*		window;
     BzfJoystick*	joystick;
