@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2008 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -152,7 +152,8 @@ void ListServerLink::finalization(char *data, unsigned int length, bool good)
 	  for (int i = 0; i < curMaxPlayers; i++) {
 	    GameKeeper::Player* gkp = GameKeeper::Player::getPlayerByIndex(i);
 	    if ((gkp != NULL) &&
-		(strcasecmp(gkp->player.getCallSign(), nick.c_str()) == 0)) {
+		(strcasecmp(gkp->player.getCallSign(), nick.c_str()) == 0) &&
+		(gkp->_LSAState == GameKeeper::Player::verified)) {
 	      gkp->setBzIdentifier(bzId);
 	      logDebugMessage(3,"Set player (%s [%i]) bzId to (%s)\n",
 		     nick.c_str(), i, bzId.c_str());
