@@ -1,5 +1,5 @@
 /* bzflag
-* Copyright (c) 1993 - 2005 Tim Riker
+* Copyright (c) 1993-2010 Tim Riker
 *
 * This package is free software;  you can redistribute it and/or
 * modify it under the terms of the license found in the file
@@ -7,29 +7,29 @@
 *
 * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
-* WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
 
 #ifdef _MSC_VER
 #pragma warning( 4: 4786)
 #endif
 
+// interface header
 #include "MasterBanList.h"
-#include "URLManager.h"
-
-MasterBanList::MasterBanList()
-{
-}
-
-MasterBanList::~MasterBanList()
-{
-
-}
 
 const std::string& MasterBanList::get ( const std::string URL )
 {
   data = "";
   // get all up on the internet and go get the thing
-	URLManager::instance().getURL(URL,data);
+  setURL(URL);
+  performWait();
   return data;
 }
+
+void MasterBanList::finalization(char *cURLdata, unsigned int length,
+				 bool good)
+{
+  if (good)
+    data = std::string(cURLdata, length);
+}
+
