@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,23 +7,22 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
+/* interface header */
+#include "CommandManager.h"
 
-// system headers
+/* system implementation headers */
 #include <ctype.h>
 #include <stdio.h>
 #include <assert.h>
 #include <string>
 
-// class-specific headers
-#include "CommandManager.h"
+/* common implementation headers */
 #include "TextUtils.h"
 
+
 // initialize the singleton
 template <>
 CommandManager* Singleton<CommandManager>::_instance = (CommandManager*)0;
@@ -66,17 +65,23 @@ std::string			CommandManager::getHelp(const std::string& name) const
 }
 
 std::string			CommandManager::run(const std::string& name,
-							    const ArgList& args) const
+							    const ArgList& args, bool* ret) const
 {
   // look up command
   Commands::const_iterator index = commands.find(name);
   if (index == commands.end())
+  {
     return TextUtils::format("Command %s not found", name.c_str());
+	if (ret)
+		*ret = false;
+  }
+  if (ret)
+	  *ret = true;
   // run it
-  return (*index->second.func)(name, args);
+  return (*index->second.func)(name, args,ret);
 }
 
-std::string			CommandManager::run(const std::string& cmd) const
+std::string			CommandManager::run(const std::string& cmd,bool *ret) const
 {
   std::string result;
   const char* scan = cmd.c_str();
@@ -104,9 +109,13 @@ std::string			CommandManager::run(const std::string& cmd) const
 
     // run it or report error
     if (scan == NULL)
+	{
+		if (ret)
+			*ret = false;
       return std::string("Error parsing command");
+	}
     else if (name[0] != '#')
-      result = run(name, args);
+      result = run(name, args,ret);
 
     // discard ; and empty commands
     while (scan != NULL && *scan == ';') {
