@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,16 +7,29 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #include "common.h"
+
+// system headers
 #include <string>
+#include <string.h>
+
+// common headers
 #include "bzfio.h"
+#include "StateDatabase.h"
 #include "bzfgl.h"
 #include "OpenGLTexture.h"
 #include "OpenGLGState.h"
 
+#ifndef _WIN32
+typedef int64_t s64;
+#else
+typedef __int64 s64;
+#endif
+
+
 //
 // OpenGLTexture::Rep
 //
@@ -151,13 +164,19 @@ bool OpenGLTexture::setupImage(const GLubyte* pixels)
     scaledHeight <<= 1;
   }
 
-  // get minimum valid size for texture (boost to 2^m x 2^n)
+  // get maximum valid size for texture (boost to 2^m x 2^n)
   GLint maxTextureSize;
   glGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxTextureSize);
 
   // hard limit, some drivers have problems with sizes greater
   // then this (espeically if you are using glTexSubImage2D)
-  const GLint bzMaxTexSize = 512;
+  const GLint dbMaxTexSize = BZDB.evalInt("maxTextureSize");
+  GLint bzMaxTexSize = 1;
+  // align the max size to a power of two  (wasteful)
+  while (bzMaxTexSize < dbMaxTexSize) {
+    bzMaxTexSize <<= 1;
+  }
+
   if ((maxTextureSize < 0) || (maxTextureSize > bzMaxTexSize)) {
     maxTextureSize = bzMaxTexSize;
   }
@@ -189,7 +208,7 @@ bool OpenGLTexture::setupImage(const GLubyte* pixels)
     delete[] unaligned;
     unaligned = unalignedScaled;
     aligned = alignedScaled;
-    DEBUG1("Scaling texture from %ix%i to %ix%i\n",
+    logDebugMessage(1,"Scaling texture from %ix%i to %ix%i\n",
 	   width, height, scaledWidth, scaledHeight);
   }
 
@@ -256,6 +275,12 @@ void OpenGLTexture::setFilter(Filter _filter)
   glBindTexture(GL_TEXTURE_2D, list);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, minifyFilter[filterIndex]);
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, magnifyFilter[filterIndex]);
+#ifdef HAVE_GLEW
+  if (GLEW_EXT_texture_filter_anisotropic) {
+    GLint aniso = BZDB.evalInt("aniso");
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, aniso);
+  }
+#endif
   glBindTexture(GL_TEXTURE_2D, binding);
 }
 
@@ -315,11 +340,11 @@ void OpenGLTexture::bind()
 }
 
 
-int OpenGLTexture::getBestFormat(int width, int height, const GLvoid* pixels)
+int OpenGLTexture::getBestFormat(int _width, int _height, const GLvoid* pixels)
 {
   // see if all pixels are achromatic
   const GLubyte* scan = (const GLubyte*)pixels;
-  const int size = width * height;
+  const int size = _width * _height;
   int i;
   for (i = 0; i < size; scan += 4, i++)
     if (scan[0] != scan[1] || scan[0] != scan[2])
@@ -363,6 +388,57 @@ int OpenGLTexture::getBestFormat(int width, int height, const GLvoid* pixels)
 }
 
 
+bool OpenGLTexture::getColorAverages(float rgba[4], bool factorAlpha) const
+{
+  if ((image == NULL) || (scaledWidth <= 0) || (scaledHeight <= 0)) {
+    return false;
+  }
+
+  factorAlpha = (factorAlpha && alpha);
+  const int channelCount = alpha ? 4 : 3;
+
+  // tally the values
+  s64 rgbaTally[4] = {0, 0, 0, 0};
+  for (int x = 0; x < scaledWidth; x++) {
+    for (int y = 0; y < scaledHeight; y++) {
+      for (int c = 0; c < channelCount; c++) {
+	const int pixelBase = 4 * (x + (y * scaledWidth));
+	if (factorAlpha) {
+	  const GLubyte alphaVal = image[pixelBase + 3];
+	  if (c == 3) {
+	    rgbaTally[3] += alphaVal;
+	  } else {
+	    rgbaTally[c] += image[pixelBase + c] * alphaVal;
+	  }
+	} else {
+	  rgbaTally[c] += image[pixelBase + c];
+	}
+      }
+    }
+  }
+
+  // calculate the alpha average
+  float maxTally = 255.0f * (scaledWidth * scaledHeight);
+  if (channelCount == 3) {
+    rgba[3] = 1.0f;
+  } else {
+    rgba[3] = (float)rgbaTally[3] / maxTally;
+  }
+
+  // adjust the maxTally for alpha weighting
+  if (factorAlpha) {
+    maxTally = maxTally * 255.0f;
+  }
+
+  // calcualte the color averages
+  for (int c = 0; c < 3; c++) {
+    rgba[c] = (float)rgbaTally[c] / maxTally;
+  }
+
+  return true;
+}
+
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
