@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,6 +19,9 @@
 // Don't try compile this if we don't have an up-to-date, working DX
 #if defined(USE_DINPUT)
 
+#pragma comment(lib, "dinput8.lib")
+#pragma comment(lib, "dxguid.lib")
+
 /* system headers */
 #include <vector>
 #include <string>
@@ -36,7 +39,7 @@ std::map<std::string, LPDIRECTINPUTEFFECT> DXJoystick::effectDatabase;
 DXJoystick::DXJoystick() : device(NULL)
 {
   HINSTANCE hinst = GetModuleHandle(NULL);
-  HRESULT success = DirectInputCreateEx(hinst, DIRECTINPUT_VERSION, IID_IDirectInput7,
+  HRESULT success = DirectInput8Create(hinst, DIRECTINPUT_VERSION, IID_IDirectInput8,
 					(void**)&directInput, NULL);
 
   if (success != DI_OK) {
@@ -77,14 +80,12 @@ void	      DXJoystick::initJoystick(const char* joystickName)
    */
   GUID thisDevice;
   for (unsigned int i = 0; i < devices.size(); i++) {
-    if (strcmp(joystickName, devices[i].tszProductName) == 0) {
-      thisDevice = devices[i].guidInstance;
-      break;
-    }
+	  if (strcmp(joystickName, devices[i].tszProductName) == 0) {
+		  thisDevice = devices[i].guidInstance;
+		  break;
+	  }
   }
-  HRESULT success = directInput->CreateDeviceEx(thisDevice,
-						IID_IDirectInputDevice7,
-						(void**)&device, NULL);
+  HRESULT success = directInput->CreateDevice(thisDevice,&device, NULL);
 
   if (success != DI_OK) {
     DXError("Could not initialize device", success);
@@ -704,7 +705,7 @@ void DXJoystick::enumerateDevices()
 
   devices.clear();
 
-  HRESULT success = directInput->EnumDevices(DIDEVTYPE_JOYSTICK,
+  HRESULT success = directInput->EnumDevices(DI8DEVCLASS_GAMECTRL,
 					     &deviceEnumCallback, NULL,
 					     DIEDFL_ATTACHEDONLY);
 
