@@ -1,9 +1,9 @@
 /* zconf.h -- configuration of the zlib compression library
- * Copyright (C) 1995-2004 Jean-loup Gailly.
+ * Copyright (C) 1995-2005 Jean-loup Gailly.
  * For conditions of distribution and use, see copyright notice in zlib.h
  */
 
-/* @(#) $Id: zconf.h,v 2.3 2005/09/28 00:24:43 timriker Exp $ */
+/* @(#) $Id: zconf.h 17845 2008-06-25 20:28:39Z timriker $ */
 
 #ifndef ZCONF_H
 #define ZCONF_H
@@ -43,6 +43,10 @@
 #  define get_crc_table	 z_get_crc_table
 #  define zError		z_zError
 
+#  define alloc_func	    z_alloc_func
+#  define free_func	     z_free_func
+#  define in_func	       z_in_func
+#  define out_func	      z_out_func
 #  define Byte		  z_Byte
 #  define uInt		  z_uInt
 #  define uLong		 z_uLong
@@ -64,8 +68,10 @@
 #if defined(_WINDOWS) && !defined(WINDOWS)
 #  define WINDOWS
 #endif
-#if (defined(_WIN32) || defined(__WIN32__)) && !defined(WIN32)
-#  define WIN32
+#if defined(_WIN32) || defined(_WIN32_WCE) || defined(__WIN32__)
+#  ifndef WIN32
+#    define WIN32
+#  endif
 #endif
 #if (defined(MSDOS) || defined(OS2) || defined(WINDOWS)) && !defined(WIN32)
 #  if !defined(__GNUC__) && !defined(__FLAT__) && !defined(__386__)
